import logging

import subprocess

logger = logging.getLogger(__name__)

class Converter(object):
    page_file_suffix = '.pdf'

    def __init__(self, options):
        self.options = options

    def convert(self, source_basename, source_suffix):
        logger.info('convert %s', source_basename)
        args = ['convert']

        color_depth = self.options.color_depth if self.options.color_mode != 'bw' else 1
        args += ['-depth', str(color_depth)]
        args += ['-density', str(self.options.resolution)]
        args += ['-compress', 'zip']
        args += [source_basename + source_suffix, source_basename + self.page_file_suffix]

        return subprocess.call(args)



# coding=utf-8
import glob

from setuptools import setup, find_packages

setup(
    name='scan-pdf',
    version='0.1.8',
    packages=find_packages(),
    scripts=glob.glob('scripts/*'),
    description='Tools for using scanners with document feeder',
    author='Andreas Würl',
    author_email='andreas@wuerl.net',
    url='https://github.com/wuan/scan-pdf',
    license='Apache-2.0',
    classifiers=[
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: Apache Software License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],
    install_requires=[],
    tests_require=['pytest-cov', 'mock', 'assertpy'],
)


import logging
import os

import subprocess

logger = logging.getLogger(__name__)


class Combiner(object):
    def __init__(self, options):
        self.options = options

    def combine(self, page_file_names):
        output_file_name = self.options.output_file_name[0]
        logger.info("combine %d files into %s", len(page_file_names), output_file_name)
        combine_args = ['pdftk']
        combine_args += page_file_names
        combine_args += ['output', os.path.basename(output_file_name), 'compress']
        return subprocess.call(combine_args)
